from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Data
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.UI.Xaml.Interop
class Binding(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Data.BindingBase
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBinding
    _classid_ = 'Microsoft.UI.Xaml.Data.Binding'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.Binding.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IBindingFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_mixinmethod
    def put_Path(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.BindingMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.BindingMode) -> Void: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_RelativeSource(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
    @winrt_mixinmethod
    def put_RelativeSource(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.RelativeSource) -> Void: ...
    @winrt_mixinmethod
    def get_ElementName(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ElementName(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Converter(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.IValueConverter: ...
    @winrt_mixinmethod
    def put_Converter(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_mixinmethod
    def get_ConverterParameter(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> IInspectable: ...
    @winrt_mixinmethod
    def put_ConverterParameter(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_ConverterLanguage(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_ConverterLanguage(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_FallbackValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> IInspectable: ...
    @winrt_mixinmethod
    def put_FallbackValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_TargetNullValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> IInspectable: ...
    @winrt_mixinmethod
    def put_TargetNullValue(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateSourceTrigger(self: win32more.Microsoft.UI.Xaml.Data.IBinding) -> win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger: ...
    @winrt_mixinmethod
    def put_UpdateSourceTrigger(self: win32more.Microsoft.UI.Xaml.Data.IBinding, value: win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger) -> Void: ...
    Converter = property(get_Converter, put_Converter)
    ConverterLanguage = property(get_ConverterLanguage, put_ConverterLanguage)
    ConverterParameter = property(get_ConverterParameter, put_ConverterParameter)
    ElementName = property(get_ElementName, put_ElementName)
    FallbackValue = property(get_FallbackValue, put_FallbackValue)
    Mode = property(get_Mode, put_Mode)
    Path = property(get_Path, put_Path)
    RelativeSource = property(get_RelativeSource, put_RelativeSource)
    Source = property(get_Source, put_Source)
    TargetNullValue = property(get_TargetNullValue, put_TargetNullValue)
    UpdateSourceTrigger = property(get_UpdateSourceTrigger, put_UpdateSourceTrigger)
class BindingBase(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingBase
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingBase'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.BindingBase.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IBindingBaseFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.BindingBase: ...
class BindingExpression(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.Data.BindingExpressionBase
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingExpression
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingExpression'
    @winrt_mixinmethod
    def get_DataItem(self: win32more.Microsoft.UI.Xaml.Data.IBindingExpression) -> IInspectable: ...
    @winrt_mixinmethod
    def get_ParentBinding(self: win32more.Microsoft.UI.Xaml.Data.IBindingExpression) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
    @winrt_mixinmethod
    def UpdateSource(self: win32more.Microsoft.UI.Xaml.Data.IBindingExpression) -> Void: ...
    DataItem = property(get_DataItem, None)
    ParentBinding = property(get_ParentBinding, None)
class BindingExpressionBase(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingExpressionBase
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingExpressionBase'
class BindingMode(Enum, Int32):
    OneWay = 1
    OneTime = 2
    TwoWay = 3
class BindingOperations(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IBindingOperations
    _classid_ = 'Microsoft.UI.Xaml.Data.BindingOperations'
    @winrt_classmethod
    def SetBinding(cls: win32more.Microsoft.UI.Xaml.Data.IBindingOperationsStatics, target: win32more.Microsoft.UI.Xaml.DependencyObject, dp: win32more.Microsoft.UI.Xaml.DependencyProperty, binding: win32more.Microsoft.UI.Xaml.Data.BindingBase) -> Void: ...
class _CollectionViewSource_Meta_(ComPtr.__class__):
    pass
class CollectionViewSource(ComPtr, metaclass=_CollectionViewSource_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource
    _classid_ = 'Microsoft.UI.Xaml.Data.CollectionViewSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.CollectionViewSource.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.UI.Xaml.Data.CollectionViewSource: ...
    @winrt_mixinmethod
    def get_Source(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> IInspectable: ...
    @winrt_mixinmethod
    def put_Source(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource, value: IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_View(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> win32more.Microsoft.UI.Xaml.Data.ICollectionView: ...
    @winrt_mixinmethod
    def get_IsSourceGrouped(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsSourceGrouped(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ItemsPath(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_mixinmethod
    def put_ItemsPath(self: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSource, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    @winrt_classmethod
    def get_SourceProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ViewProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_IsSourceGroupedProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_classmethod
    def get_ItemsPathProperty(cls: win32more.Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsSourceGrouped = property(get_IsSourceGrouped, put_IsSourceGrouped)
    ItemsPath = property(get_ItemsPath, put_ItemsPath)
    Source = property(get_Source, put_Source)
    View = property(get_View, None)
    _CollectionViewSource_Meta_.IsSourceGroupedProperty = property(get_IsSourceGroupedProperty, None)
    _CollectionViewSource_Meta_.ItemsPathProperty = property(get_ItemsPathProperty, None)
    _CollectionViewSource_Meta_.SourceProperty = property(get_SourceProperty, None)
    _CollectionViewSource_Meta_.ViewProperty = property(get_ViewProperty, None)
class CurrentChangingEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Data.CurrentChangingEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs.CreateInstance(*args, None, None))
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs.CreateWithCancelableParameter(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
    @winrt_factorymethod
    def CreateWithCancelableParameter(cls: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgsFactory, isCancelable: Boolean, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IsCancelable(self: win32more.Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs) -> Boolean: ...
    Cancel = property(get_Cancel, put_Cancel)
    IsCancelable = property(get_IsCancelable, None)
class CurrentChangingEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{3d2a98dd-95b3-5fd5-93b4-a1a2599f225c}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs) -> Void: ...
class DataErrorsChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgsFactory, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs: ...
    @winrt_mixinmethod
    def get_PropertyName(self: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_PropertyName(self: win32more.Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs, value: WinRT_String) -> Void: ...
    PropertyName = property(get_PropertyName, put_PropertyName)
class IBinding(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBinding'
    _iid_ = Guid('{501ea0e8-edd4-59de-8845-76af2eabbe00}')
    @winrt_commethod(6)
    def get_Path(self) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_commethod(7)
    def put_Path(self, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    @winrt_commethod(8)
    def get_Mode(self) -> win32more.Microsoft.UI.Xaml.Data.BindingMode: ...
    @winrt_commethod(9)
    def put_Mode(self, value: win32more.Microsoft.UI.Xaml.Data.BindingMode) -> Void: ...
    @winrt_commethod(10)
    def get_Source(self) -> IInspectable: ...
    @winrt_commethod(11)
    def put_Source(self, value: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_RelativeSource(self) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
    @winrt_commethod(13)
    def put_RelativeSource(self, value: win32more.Microsoft.UI.Xaml.Data.RelativeSource) -> Void: ...
    @winrt_commethod(14)
    def get_ElementName(self) -> WinRT_String: ...
    @winrt_commethod(15)
    def put_ElementName(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(16)
    def get_Converter(self) -> win32more.Microsoft.UI.Xaml.Data.IValueConverter: ...
    @winrt_commethod(17)
    def put_Converter(self, value: win32more.Microsoft.UI.Xaml.Data.IValueConverter) -> Void: ...
    @winrt_commethod(18)
    def get_ConverterParameter(self) -> IInspectable: ...
    @winrt_commethod(19)
    def put_ConverterParameter(self, value: IInspectable) -> Void: ...
    @winrt_commethod(20)
    def get_ConverterLanguage(self) -> WinRT_String: ...
    @winrt_commethod(21)
    def put_ConverterLanguage(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(22)
    def get_FallbackValue(self) -> IInspectable: ...
    @winrt_commethod(23)
    def put_FallbackValue(self, value: IInspectable) -> Void: ...
    @winrt_commethod(24)
    def get_TargetNullValue(self) -> IInspectable: ...
    @winrt_commethod(25)
    def put_TargetNullValue(self, value: IInspectable) -> Void: ...
    @winrt_commethod(26)
    def get_UpdateSourceTrigger(self) -> win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger: ...
    @winrt_commethod(27)
    def put_UpdateSourceTrigger(self, value: win32more.Microsoft.UI.Xaml.Data.UpdateSourceTrigger) -> Void: ...
    Converter = property(get_Converter, put_Converter)
    ConverterLanguage = property(get_ConverterLanguage, put_ConverterLanguage)
    ConverterParameter = property(get_ConverterParameter, put_ConverterParameter)
    ElementName = property(get_ElementName, put_ElementName)
    FallbackValue = property(get_FallbackValue, put_FallbackValue)
    Mode = property(get_Mode, put_Mode)
    Path = property(get_Path, put_Path)
    RelativeSource = property(get_RelativeSource, put_RelativeSource)
    Source = property(get_Source, put_Source)
    TargetNullValue = property(get_TargetNullValue, put_TargetNullValue)
    UpdateSourceTrigger = property(get_UpdateSourceTrigger, put_UpdateSourceTrigger)
class IBindingBase(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingBase'
    _iid_ = Guid('{91ddd141-5944-50ef-b85e-218e463f7a73}')
class IBindingBaseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingBaseFactory'
    _iid_ = Guid('{c8a866c5-f6f3-5f7a-9592-d385af48bd8f}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.BindingBase: ...
class IBindingExpression(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpression'
    _iid_ = Guid('{4c023916-37bc-5b07-bc9d-15c547bd9b26}')
    @winrt_commethod(6)
    def get_DataItem(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_ParentBinding(self) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
    @winrt_commethod(8)
    def UpdateSource(self) -> Void: ...
    DataItem = property(get_DataItem, None)
    ParentBinding = property(get_ParentBinding, None)
class IBindingExpressionBase(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpressionBase'
    _iid_ = Guid('{8825e5a9-d9a3-5e87-bcd8-c63133d29029}')
class IBindingExpressionBaseFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpressionBaseFactory'
    _iid_ = Guid('{41d643b9-2629-5451-a716-596c0848b5dc}')
class IBindingExpressionFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingExpressionFactory'
    _iid_ = Guid('{086cae14-81a1-588b-b619-05ee84c0f089}')
class IBindingFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingFactory'
    _iid_ = Guid('{cb2de749-b115-5f67-b64a-797d54885d5c}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.Binding: ...
class IBindingOperations(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingOperations'
    _iid_ = Guid('{9a319b95-aabe-5075-b227-8eb07e443d8b}')
class IBindingOperationsStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IBindingOperationsStatics'
    _iid_ = Guid('{1e1bdbd3-fca5-5c85-b87d-b504cd8fa8ac}')
    @winrt_commethod(6)
    def SetBinding(self, target: win32more.Microsoft.UI.Xaml.DependencyObject, dp: win32more.Microsoft.UI.Xaml.DependencyProperty, binding: win32more.Microsoft.UI.Xaml.Data.BindingBase) -> Void: ...
class ICollectionView(ComPtr):
    extends: IInspectable
    implements: Tuple[SequenceProtocol[IInspectable]]
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionView'
    _iid_ = Guid('{f8bb90d8-e008-5d65-8c97-7bb790a4230c}')
    @winrt_commethod(6)
    def get_CurrentItem(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_CurrentPosition(self) -> Int32: ...
    @winrt_commethod(8)
    def get_IsCurrentAfterLast(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_IsCurrentBeforeFirst(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_CollectionGroups(self) -> win32more.Windows.Foundation.Collections.IObservableVector[IInspectable]: ...
    @winrt_commethod(11)
    def get_HasMoreItems(self) -> Boolean: ...
    @winrt_commethod(12)
    def add_CurrentChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_CurrentChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_CurrentChanging(self, handler: win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_CurrentChanging(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def MoveCurrentTo(self, item: IInspectable) -> Boolean: ...
    @winrt_commethod(17)
    def MoveCurrentToPosition(self, index: Int32) -> Boolean: ...
    @winrt_commethod(18)
    def MoveCurrentToFirst(self) -> Boolean: ...
    @winrt_commethod(19)
    def MoveCurrentToLast(self) -> Boolean: ...
    @winrt_commethod(20)
    def MoveCurrentToNext(self) -> Boolean: ...
    @winrt_commethod(21)
    def MoveCurrentToPrevious(self) -> Boolean: ...
    @winrt_commethod(22)
    def LoadMoreItemsAsync(self, count: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Data.LoadMoreItemsResult]: ...
    CollectionGroups = property(get_CollectionGroups, None)
    CurrentItem = property(get_CurrentItem, None)
    CurrentPosition = property(get_CurrentPosition, None)
    HasMoreItems = property(get_HasMoreItems, None)
    IsCurrentAfterLast = property(get_IsCurrentAfterLast, None)
    IsCurrentBeforeFirst = property(get_IsCurrentBeforeFirst, None)
    CurrentChanged = event()
    CurrentChanging = event()
class ICollectionViewFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewFactory'
    _iid_ = Guid('{d971f795-5728-5bef-9602-43f2c4250e56}')
    @winrt_commethod(6)
    def CreateView(self) -> win32more.Microsoft.UI.Xaml.Data.ICollectionView: ...
class ICollectionViewGroup(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewGroup'
    _iid_ = Guid('{96a08da8-be38-5ae0-903d-6fb6111e61f5}')
    @winrt_commethod(6)
    def get_Group(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_GroupItems(self) -> win32more.Windows.Foundation.Collections.IObservableVector[IInspectable]: ...
    Group = property(get_Group, None)
    GroupItems = property(get_GroupItems, None)
class ICollectionViewSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewSource'
    _iid_ = Guid('{a45e3b3a-f31e-5bbb-8a7c-70cf5c64bc3f}')
    @winrt_commethod(6)
    def get_Source(self) -> IInspectable: ...
    @winrt_commethod(7)
    def put_Source(self, value: IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_View(self) -> win32more.Microsoft.UI.Xaml.Data.ICollectionView: ...
    @winrt_commethod(9)
    def get_IsSourceGrouped(self) -> Boolean: ...
    @winrt_commethod(10)
    def put_IsSourceGrouped(self, value: Boolean) -> Void: ...
    @winrt_commethod(11)
    def get_ItemsPath(self) -> win32more.Microsoft.UI.Xaml.PropertyPath: ...
    @winrt_commethod(12)
    def put_ItemsPath(self, value: win32more.Microsoft.UI.Xaml.PropertyPath) -> Void: ...
    IsSourceGrouped = property(get_IsSourceGrouped, put_IsSourceGrouped)
    ItemsPath = property(get_ItemsPath, put_ItemsPath)
    Source = property(get_Source, put_Source)
    View = property(get_View, None)
class ICollectionViewSourceStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICollectionViewSourceStatics'
    _iid_ = Guid('{e282f10f-d4b1-5769-8a11-30f739e6113b}')
    @winrt_commethod(6)
    def get_SourceProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(7)
    def get_ViewProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(8)
    def get_IsSourceGroupedProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    @winrt_commethod(9)
    def get_ItemsPathProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    IsSourceGroupedProperty = property(get_IsSourceGroupedProperty, None)
    ItemsPathProperty = property(get_ItemsPathProperty, None)
    SourceProperty = property(get_SourceProperty, None)
    ViewProperty = property(get_ViewProperty, None)
class ICurrentChangingEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICurrentChangingEventArgs'
    _iid_ = Guid('{63e42ed6-e14a-51ea-9cb1-72f9c907dc80}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IsCancelable(self) -> Boolean: ...
    Cancel = property(get_Cancel, put_Cancel)
    IsCancelable = property(get_IsCancelable, None)
class ICurrentChangingEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICurrentChangingEventArgsFactory'
    _iid_ = Guid('{3670f48a-ac2c-5352-8a4b-6b977a08e5f8}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
    @winrt_commethod(7)
    def CreateWithCancelableParameter(self, isCancelable: Boolean, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.CurrentChangingEventArgs: ...
class ICustomProperty(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICustomProperty'
    _iid_ = Guid('{30da92c0-23e8-42a0-ae7c-734a0e5d2782}')
    @winrt_commethod(6)
    def get_Type(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(7)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def GetValue(self, target: IInspectable) -> IInspectable: ...
    @winrt_commethod(9)
    def SetValue(self, target: IInspectable, value: IInspectable) -> Void: ...
    @winrt_commethod(10)
    def GetIndexedValue(self, target: IInspectable, index: IInspectable) -> IInspectable: ...
    @winrt_commethod(11)
    def SetIndexedValue(self, target: IInspectable, value: IInspectable, index: IInspectable) -> Void: ...
    @winrt_commethod(12)
    def get_CanWrite(self) -> Boolean: ...
    @winrt_commethod(13)
    def get_CanRead(self) -> Boolean: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    Name = property(get_Name, None)
    Type = property(get_Type, None)
class ICustomPropertyProvider(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ICustomPropertyProvider'
    _iid_ = Guid('{7c925755-3e48-42b4-8677-76372267033f}')
    @winrt_commethod(6)
    def GetCustomProperty(self, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Data.ICustomProperty: ...
    @winrt_commethod(7)
    def GetIndexedProperty(self, name: WinRT_String, type: win32more.Windows.UI.Xaml.Interop.TypeName) -> win32more.Microsoft.UI.Xaml.Data.ICustomProperty: ...
    @winrt_commethod(8)
    def GetStringRepresentation(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Type(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Type = property(get_Type, None)
class IDataErrorsChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgs'
    _iid_ = Guid('{d026dd64-5f26-5f15-a86a-0dec8a431796}')
    @winrt_commethod(6)
    def get_PropertyName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_PropertyName(self, value: WinRT_String) -> Void: ...
    PropertyName = property(get_PropertyName, put_PropertyName)
class IDataErrorsChangedEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IDataErrorsChangedEventArgsFactory'
    _iid_ = Guid('{62d0bd1e-b85f-5fcc-842a-7cb0dda37fe5}')
    @winrt_commethod(6)
    def CreateInstance(self, name: WinRT_String) -> win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs: ...
class IItemIndexRange(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IItemIndexRange'
    _iid_ = Guid('{eba09846-2554-5b86-ac17-614f05105fa2}')
    @winrt_commethod(6)
    def get_FirstIndex(self) -> Int32: ...
    @winrt_commethod(7)
    def get_Length(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_LastIndex(self) -> Int32: ...
    FirstIndex = property(get_FirstIndex, None)
    LastIndex = property(get_LastIndex, None)
    Length = property(get_Length, None)
class IItemIndexRangeFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IItemIndexRangeFactory'
    _iid_ = Guid('{9fc73213-eda0-5238-aa2c-401c9921f0f9}')
    @winrt_commethod(6)
    def CreateInstance(self, firstIndex: Int32, length: UInt32, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.ItemIndexRange: ...
class IItemsRangeInfo(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Microsoft.UI.Xaml.Data.IItemsRangeInfo'
    _iid_ = Guid('{b8376d08-85fb-563b-8273-39ef2d138256}')
    @winrt_commethod(6)
    def RangesChanged(self, visibleRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange, trackedItems: win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Data.ItemIndexRange]) -> Void: ...
class INotifyDataErrorInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.INotifyDataErrorInfo'
    _iid_ = Guid('{0ee6c2cc-273e-567d-bc0a-1dd87ee51eba}')
    @winrt_commethod(6)
    def get_HasErrors(self) -> Boolean: ...
    @winrt_commethod(7)
    def add_ErrorsChanged(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Microsoft.UI.Xaml.Data.DataErrorsChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_ErrorsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def GetErrors(self, propertyName: WinRT_String) -> win32more.Windows.Foundation.Collections.IIterable[IInspectable]: ...
    HasErrors = property(get_HasErrors, None)
    ErrorsChanged = event()
class INotifyPropertyChanged(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.INotifyPropertyChanged'
    _iid_ = Guid('{90b17601-b065-586e-83d9-9adc3a695284}')
    @winrt_commethod(6)
    def add_PropertyChanged(self, handler: win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventHandler) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_PropertyChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PropertyChanged = event()
class IPropertyChangedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IPropertyChangedEventArgs'
    _iid_ = Guid('{63d0c952-396b-54f4-af8c-ba8724a427bf}')
    @winrt_commethod(6)
    def get_PropertyName(self) -> WinRT_String: ...
    PropertyName = property(get_PropertyName, None)
class IPropertyChangedEventArgsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IPropertyChangedEventArgsFactory'
    _iid_ = Guid('{7c0c27a8-0b41-5070-b160-fc9ae960a36c}')
    @winrt_commethod(6)
    def CreateInstance(self, name: WinRT_String, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs: ...
class IRelativeSource(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IRelativeSource'
    _iid_ = Guid('{7ffc8126-5dd8-58bb-b686-c71eddea07b2}')
    @winrt_commethod(6)
    def get_Mode(self) -> win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode: ...
    @winrt_commethod(7)
    def put_Mode(self, value: win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class IRelativeSourceFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IRelativeSourceFactory'
    _iid_ = Guid('{8518522c-85e3-5ae1-b9e9-28ea43c2051e}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
class ISelectionInfo(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ISelectionInfo'
    _iid_ = Guid('{1b84c26b-9532-5803-935b-a03bf7e875dc}')
    @winrt_commethod(6)
    def SelectRange(self, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(7)
    def DeselectRange(self, itemIndexRange: win32more.Microsoft.UI.Xaml.Data.ItemIndexRange) -> Void: ...
    @winrt_commethod(8)
    def IsSelected(self, index: Int32) -> Boolean: ...
    @winrt_commethod(9)
    def GetSelectedRanges(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Microsoft.UI.Xaml.Data.ItemIndexRange]: ...
class ISupportIncrementalLoading(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.ISupportIncrementalLoading'
    _iid_ = Guid('{d8f9b586-a64a-5ff8-868e-204e144f2cf4}')
    @winrt_commethod(6)
    def LoadMoreItemsAsync(self, count: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.UI.Xaml.Data.LoadMoreItemsResult]: ...
    @winrt_commethod(7)
    def get_HasMoreItems(self) -> Boolean: ...
    HasMoreItems = property(get_HasMoreItems, None)
class IValueConverter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Data.IValueConverter'
    _iid_ = Guid('{afdd2bff-10f5-5173-b7c0-3590bd96cb35}')
    @winrt_commethod(6)
    def Convert(self, value: IInspectable, targetType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, language: WinRT_String) -> IInspectable: ...
    @winrt_commethod(7)
    def ConvertBack(self, value: IInspectable, targetType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, language: WinRT_String) -> IInspectable: ...
class ItemIndexRange(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange
    _classid_ = 'Microsoft.UI.Xaml.Data.ItemIndexRange'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.ItemIndexRange.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IItemIndexRangeFactory, firstIndex: Int32, length: UInt32, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.ItemIndexRange: ...
    @winrt_mixinmethod
    def get_FirstIndex(self: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange) -> Int32: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange) -> UInt32: ...
    @winrt_mixinmethod
    def get_LastIndex(self: win32more.Microsoft.UI.Xaml.Data.IItemIndexRange) -> Int32: ...
    FirstIndex = property(get_FirstIndex, None)
    LastIndex = property(get_LastIndex, None)
    Length = property(get_Length, None)
class LoadMoreItemsResult(Structure):
    Count: UInt32
class PropertyChangedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Data.IPropertyChangedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Data.PropertyChangedEventArgs'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IPropertyChangedEventArgsFactory, name: WinRT_String, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs: ...
    @winrt_mixinmethod
    def get_PropertyName(self: win32more.Microsoft.UI.Xaml.Data.IPropertyChangedEventArgs) -> WinRT_String: ...
    PropertyName = property(get_PropertyName, None)
class PropertyChangedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{e3de52f6-1e32-5da6-bb2d-b5b6096c962d}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Data.PropertyChangedEventArgs) -> Void: ...
class RelativeSource(ComPtr):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Data.IRelativeSource
    _classid_ = 'Microsoft.UI.Xaml.Data.RelativeSource'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Data.RelativeSource.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Data.IRelativeSourceFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Data.RelativeSource: ...
    @winrt_mixinmethod
    def get_Mode(self: win32more.Microsoft.UI.Xaml.Data.IRelativeSource) -> win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode: ...
    @winrt_mixinmethod
    def put_Mode(self: win32more.Microsoft.UI.Xaml.Data.IRelativeSource, value: win32more.Microsoft.UI.Xaml.Data.RelativeSourceMode) -> Void: ...
    Mode = property(get_Mode, put_Mode)
class RelativeSourceMode(Enum, Int32):
    None_ = 0
    TemplatedParent = 1
    Self = 2
class UpdateSourceTrigger(Enum, Int32):
    Default = 0
    PropertyChanged = 1
    Explicit = 2
    LostFocus = 3


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.AI
import win32more.Microsoft.Windows.AI.ContentSafety
import win32more.Microsoft.Windows.AI.Text
import win32more.Windows.Foundation
class ILanguageModel(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModel'
    _iid_ = Guid('{6331c629-8c86-5bfe-8c4e-9ca5573cc14b}')
class ILanguageModelContext(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelContext'
    _iid_ = Guid('{518b305c-7b69-5a33-8129-d47d6b8eec4e}')
class ILanguageModelOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelOptions'
    _iid_ = Guid('{7f380003-5a09-5f1f-afb0-aa483e3670cc}')
    @winrt_commethod(6)
    def get_Temperature(self) -> Single: ...
    @winrt_commethod(7)
    def put_Temperature(self, value: Single) -> Void: ...
    @winrt_commethod(8)
    def get_TopP(self) -> Single: ...
    @winrt_commethod(9)
    def put_TopP(self, value: Single) -> Void: ...
    @winrt_commethod(10)
    def get_TopK(self) -> UInt32: ...
    @winrt_commethod(11)
    def put_TopK(self, value: UInt32) -> Void: ...
    @winrt_commethod(12)
    def get_ContentFilterOptions(self) -> win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions: ...
    @winrt_commethod(13)
    def put_ContentFilterOptions(self, value: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> Void: ...
    ContentFilterOptions = property(get_ContentFilterOptions, put_ContentFilterOptions)
    Temperature = property(get_Temperature, put_Temperature)
    TopK = property(get_TopK, put_TopK)
    TopP = property(get_TopP, put_TopP)
class ILanguageModelResponseResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelResponseResult'
    _iid_ = Guid('{3a256fff-a426-5d3b-8e4b-3ac84162471e}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
    Text = property(get_Text, None)
class ILanguageModelStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ILanguageModelStatics'
    _iid_ = Guid('{8f18f9af-6095-553b-8d9d-6bcc98026546}')
    @winrt_commethod(6)
    def GetReadyState(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_commethod(7)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_commethod(8)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Text.LanguageModel]: ...
class ITextRewriter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextRewriter'
    _iid_ = Guid('{eb1e7cf0-e110-506c-b0ea-7a288d8e7778}')
    @winrt_commethod(6)
    def RewriteAsync(self, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, WinRT_String]: ...
class ITextRewriterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextRewriterFactory'
    _iid_ = Guid('{f452e60d-ef50-5bc9-b483-217d5b4e7151}')
    @winrt_commethod(6)
    def CreateInstance(self, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextRewriter: ...
class ITextSummarizer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizer'
    _iid_ = Guid('{eef548c5-d7bc-50be-a8ab-29e241b78bd1}')
    @winrt_commethod(6)
    def SummarizeAsync(self, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, WinRT_String]: ...
    @winrt_commethod(7)
    def SummarizeParagraphAsync(self, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, WinRT_String]: ...
class ITextSummarizerFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextSummarizerFactory'
    _iid_ = Guid('{b6a75913-4a1e-59e7-856a-ae7ab2383864}')
    @winrt_commethod(6)
    def CreateInstance(self, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextSummarizer: ...
class ITextToTableConverter(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableConverter'
    _iid_ = Guid('{a008d9ad-25ce-5a6b-9ceb-d8e95d04e10b}')
    @winrt_commethod(6)
    def ConvertAsync(self, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.TextToTableResponseResult, WinRT_String]: ...
class ITextToTableConverterFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableConverterFactory'
    _iid_ = Guid('{bb84cbb5-19c8-5857-b65d-705aa1486404}')
    @winrt_commethod(6)
    def CreateInstance(self, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextToTableConverter: ...
class ITextToTableResponseResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableResponseResult'
    _iid_ = Guid('{391fbf11-59cd-575d-834a-9ef823116f98}')
    @winrt_commethod(6)
    def GetRows(self) -> ReceiveArray[win32more.Microsoft.Windows.AI.Text.TextToTableRow]: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_commethod(8)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class ITextToTableRow(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Text.ITextToTableRow'
    _iid_ = Guid('{036294fe-e53c-5e66-93d2-7c92338db881}')
    @winrt_commethod(6)
    def GetColumns(self) -> ReceiveArray[WinRT_String]: ...
class LanguageModel(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModel
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModel'
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetReadyState(cls: win32more.Microsoft.Windows.AI.Text.ILanguageModelStatics) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_classmethod
    def EnsureReadyAsync(cls: win32more.Microsoft.Windows.AI.Text.ILanguageModelStatics) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Microsoft.Windows.AI.Text.ILanguageModelStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Text.LanguageModel]: ...
class LanguageModelContext(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelContext
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelContext'
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
LanguageModelContract: UInt32 = 131072
class LanguageModelOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.LanguageModelOptions.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Microsoft.Windows.AI.Text.LanguageModelOptions: ...
    @winrt_mixinmethod
    def get_Temperature(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> Single: ...
    @winrt_mixinmethod
    def put_Temperature(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_TopP(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> Single: ...
    @winrt_mixinmethod
    def put_TopP(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: Single) -> Void: ...
    @winrt_mixinmethod
    def get_TopK(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> UInt32: ...
    @winrt_mixinmethod
    def put_TopK(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ContentFilterOptions(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions) -> win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions: ...
    @winrt_mixinmethod
    def put_ContentFilterOptions(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelOptions, value: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> Void: ...
    ContentFilterOptions = property(get_ContentFilterOptions, put_ContentFilterOptions)
    Temperature = property(get_Temperature, put_Temperature)
    TopK = property(get_TopK, put_TopK)
    TopP = property(get_TopP, put_TopP)
class LanguageModelResponseResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult
    _classid_ = 'Microsoft.Windows.AI.Text.LanguageModelResponseResult'
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.Text.ILanguageModelResponseResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
    Text = property(get_Text, None)
class LanguageModelResponseStatus(Enum, Int32):
    Complete = 0
    InProgress = 1
    BlockedByPolicy = 2
    PromptLargerThanContext = 3
    PromptBlockedByContentModeration = 4
    ResponseBlockedByContentModeration = 5
    Error = 6
TextIntelligenceContract: UInt32 = 131072
class TextRewriter(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextRewriter
    _classid_ = 'Microsoft.Windows.AI.Text.TextRewriter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.TextRewriter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Text.ITextRewriterFactory, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextRewriter: ...
    @winrt_mixinmethod
    def RewriteAsync(self: win32more.Microsoft.Windows.AI.Text.ITextRewriter, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, WinRT_String]: ...
class TextSummarizer(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextSummarizer
    _classid_ = 'Microsoft.Windows.AI.Text.TextSummarizer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.TextSummarizer.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Text.ITextSummarizerFactory, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextSummarizer: ...
    @winrt_mixinmethod
    def SummarizeAsync(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, WinRT_String]: ...
    @winrt_mixinmethod
    def SummarizeParagraphAsync(self: win32more.Microsoft.Windows.AI.Text.ITextSummarizer, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.LanguageModelResponseResult, WinRT_String]: ...
class TextToTableConverter(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextToTableConverter
    _classid_ = 'Microsoft.Windows.AI.Text.TextToTableConverter'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Microsoft.Windows.AI.Text.TextToTableConverter.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Text.ITextToTableConverterFactory, languageModel: win32more.Microsoft.Windows.AI.Text.LanguageModel) -> win32more.Microsoft.Windows.AI.Text.TextToTableConverter: ...
    @winrt_mixinmethod
    def ConvertAsync(self: win32more.Microsoft.Windows.AI.Text.ITextToTableConverter, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Text.TextToTableResponseResult, WinRT_String]: ...
class TextToTableResponseResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult
    _classid_ = 'Microsoft.Windows.AI.Text.TextToTableResponseResult'
    @winrt_mixinmethod
    def GetRows(self: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult) -> ReceiveArray[win32more.Microsoft.Windows.AI.Text.TextToTableRow]: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult) -> win32more.Microsoft.Windows.AI.Text.LanguageModelResponseStatus: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Microsoft.Windows.AI.Text.ITextToTableResponseResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    Status = property(get_Status, None)
class TextToTableRow(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Text.ITextToTableRow
    _classid_ = 'Microsoft.Windows.AI.Text.TextToTableRow'
    @winrt_mixinmethod
    def GetColumns(self: win32more.Microsoft.Windows.AI.Text.ITextToTableRow) -> ReceiveArray[WinRT_String]: ...


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Graphics.Imaging
import win32more.Microsoft.Windows.AI
import win32more.Microsoft.Windows.AI.ContentSafety
import win32more.Microsoft.Windows.AI.Imaging
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics
import win32more.Windows.Graphics.Imaging
class IImageDescriptionGenerator(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageDescriptionGenerator'
    _iid_ = Guid('{576b989e-9829-5682-91b0-a7110fa7d51e}')
    @winrt_commethod(6)
    def DescribeAsync(self, image: win32more.Microsoft.Graphics.Imaging.ImageBuffer, kind: win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionKind, contentFilterOptions: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionResult, WinRT_String]: ...
class IImageDescriptionGeneratorStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageDescriptionGeneratorStatics'
    _iid_ = Guid('{5fb50b2a-5700-55a7-b413-6073b4b7f175}')
    @winrt_commethod(6)
    def GetReadyState(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_commethod(7)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_commethod(8)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionGenerator]: ...
class IImageDescriptionResult(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageDescriptionResult'
    _iid_ = Guid('{a066dd0c-110b-5275-a635-52bed7519a2f}')
    @winrt_commethod(6)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Status(self) -> win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionResultStatus: ...
    Description = property(get_Description, None)
    Status = property(get_Status, None)
class IImageObjectExtractor(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageObjectExtractor'
    _iid_ = Guid('{2919fdc0-d772-5fd9-a8b7-ffb56010c99c}')
    @winrt_commethod(6)
    def GetSoftwareBitmapObjectMask(self, hint: win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(7)
    def GetImageBufferObjectMask(self, hint: win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint) -> win32more.Microsoft.Graphics.Imaging.ImageBuffer: ...
class IImageObjectExtractorHint(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageObjectExtractorHint'
    _iid_ = Guid('{1bd8d67c-8a7a-5fe7-98a5-cbdfeb509452}')
    @winrt_commethod(6)
    def get_IncludeRects(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.RectInt32]: ...
    @winrt_commethod(7)
    def get_IncludePoints(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_commethod(8)
    def get_ExcludePoints(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.PointInt32]: ...
    ExcludePoints = property(get_ExcludePoints, None)
    IncludePoints = property(get_IncludePoints, None)
    IncludeRects = property(get_IncludeRects, None)
class IImageObjectExtractorHintFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageObjectExtractorHintFactory'
    _iid_ = Guid('{5028f206-145d-5a70-9a51-e17e60cfbad8}')
    @winrt_commethod(6)
    def CreateInstance(self, includeRects: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Graphics.RectInt32], includePoints: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Graphics.PointInt32], excludePoints: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Graphics.PointInt32]) -> win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint: ...
class IImageObjectExtractorStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageObjectExtractorStatics'
    _iid_ = Guid('{38fa261e-2c33-54cb-9e10-98d50685743d}')
    @winrt_commethod(6)
    def CreateWithSoftwareBitmapAsync(self, softwareBitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractor]: ...
    @winrt_commethod(7)
    def CreateWithImageBufferAsync(self, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractor]: ...
    @winrt_commethod(8)
    def GetReadyState(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_commethod(9)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
class IImageScaler(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageScaler'
    _iid_ = Guid('{06eec88e-91c5-5326-8128-2807faafa571}')
    @winrt_commethod(6)
    def ScaleSoftwareBitmap(self, softwareBitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap, width: Int32, height: Int32) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(7)
    def ScaleImageBuffer(self, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer, width: Int32, height: Int32) -> win32more.Microsoft.Graphics.Imaging.ImageBuffer: ...
    @winrt_commethod(8)
    def get_MaxSupportedScaleFactor(self) -> Int32: ...
    MaxSupportedScaleFactor = property(get_MaxSupportedScaleFactor, None)
class IImageScalerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IImageScalerStatics'
    _iid_ = Guid('{75380c81-9c7f-544b-9337-6e638cfb464a}')
    @winrt_commethod(6)
    def GetReadyState(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_commethod(7)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_commethod(8)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageScaler]: ...
class IRecognizedLine(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IRecognizedLine'
    _iid_ = Guid('{612a6be6-f6bb-53c9-84ce-f0a5e565faa7}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_BoundingBox(self) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedTextBoundingBox: ...
    @winrt_commethod(8)
    def get_Words(self) -> ReceiveArray[win32more.Microsoft.Windows.AI.Imaging.RecognizedWord]: ...
    @winrt_commethod(9)
    def get_Style(self) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedLineStyle: ...
    @winrt_commethod(10)
    def get_LineStyleConfidence(self) -> Single: ...
    BoundingBox = property(get_BoundingBox, None)
    LineStyleConfidence = property(get_LineStyleConfidence, None)
    Style = property(get_Style, None)
    Text = property(get_Text, None)
    Words = property(get_Words, None)
class IRecognizedText(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IRecognizedText'
    _iid_ = Guid('{ae4766d3-2924-57a6-b3d3-b866f59b9972}')
    @winrt_commethod(6)
    def get_Lines(self) -> ReceiveArray[win32more.Microsoft.Windows.AI.Imaging.RecognizedLine]: ...
    @winrt_commethod(7)
    def get_TextAngle(self) -> Single: ...
    Lines = property(get_Lines, None)
    TextAngle = property(get_TextAngle, None)
class IRecognizedWord(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.IRecognizedWord'
    _iid_ = Guid('{6b53daab-3410-5088-826a-0788a1ee3b52}')
    @winrt_commethod(6)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_BoundingBox(self) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedTextBoundingBox: ...
    @winrt_commethod(8)
    def get_MatchConfidence(self) -> Single: ...
    BoundingBox = property(get_BoundingBox, None)
    MatchConfidence = property(get_MatchConfidence, None)
    Text = property(get_Text, None)
class ITextRecognizer(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.ITextRecognizer'
    _iid_ = Guid('{be7bf6c0-30f6-570d-bd92-3ffe5665d933}')
    @winrt_commethod(6)
    def RecognizeTextFromImageAsync(self, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.RecognizedText]: ...
    @winrt_commethod(7)
    def RecognizeTextFromImage(self, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedText: ...
class ITextRecognizerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.AI.Imaging.ITextRecognizerStatics'
    _iid_ = Guid('{3788c2fd-e496-53ab-85a7-e54a135824e9}')
    @winrt_commethod(6)
    def GetReadyState(self) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_commethod(7)
    def EnsureReadyAsync(self) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_commethod(8)
    def CreateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.TextRecognizer]: ...
ImageDescriptionContract: UInt32 = 65536
class ImageDescriptionGenerator(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionGenerator
    _classid_ = 'Microsoft.Windows.AI.Imaging.ImageDescriptionGenerator'
    @winrt_mixinmethod
    def DescribeAsync(self: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionGenerator, image: win32more.Microsoft.Graphics.Imaging.ImageBuffer, kind: win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionKind, contentFilterOptions: win32more.Microsoft.Windows.AI.ContentSafety.ContentFilterOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionResult, WinRT_String]: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetReadyState(cls: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionGeneratorStatics) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_classmethod
    def EnsureReadyAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionGeneratorStatics) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionGeneratorStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionGenerator]: ...
class ImageDescriptionKind(Enum, Int32):
    BriefDescription = 0
    DetailedDescription = 1
    DiagramDescription = 2
    AccessibleDescription = 3
class ImageDescriptionResult(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionResult
    _classid_ = 'Microsoft.Windows.AI.Imaging.ImageDescriptionResult'
    @winrt_mixinmethod
    def get_Description(self: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionResult) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Status(self: win32more.Microsoft.Windows.AI.Imaging.IImageDescriptionResult) -> win32more.Microsoft.Windows.AI.Imaging.ImageDescriptionResultStatus: ...
    Description = property(get_Description, None)
    Status = property(get_Status, None)
class ImageDescriptionResultStatus(Enum, Int32):
    Complete = 0
    InProgress = 1
    BlockedByPolicy = 2
    ImageBlockedByContentModeration = 3
    TextInImageBlockedByContentModeration = 4
    DescriptionTextBlockedByContentModeration = 5
    ImageHasTooMuchText = 6
    InternalError = 7
class ImageObjectExtractor(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractor
    _classid_ = 'Microsoft.Windows.AI.Imaging.ImageObjectExtractor'
    @winrt_mixinmethod
    def GetSoftwareBitmapObjectMask(self: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractor, hint: win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_mixinmethod
    def GetImageBufferObjectMask(self: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractor, hint: win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint) -> win32more.Microsoft.Graphics.Imaging.ImageBuffer: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def CreateWithSoftwareBitmapAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorStatics, softwareBitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractor]: ...
    @winrt_classmethod
    def CreateWithImageBufferAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorStatics, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractor]: ...
    @winrt_classmethod
    def GetReadyState(cls: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorStatics) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_classmethod
    def EnsureReadyAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorStatics) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
ImageObjectExtractorContract: UInt32 = 65536
class ImageObjectExtractorHint(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorHint
    _classid_ = 'Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorHintFactory, includeRects: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Graphics.RectInt32], includePoints: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Graphics.PointInt32], excludePoints: win32more.Windows.Foundation.Collections.IVector[win32more.Windows.Graphics.PointInt32]) -> win32more.Microsoft.Windows.AI.Imaging.ImageObjectExtractorHint: ...
    @winrt_mixinmethod
    def get_IncludeRects(self: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorHint) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.RectInt32]: ...
    @winrt_mixinmethod
    def get_IncludePoints(self: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorHint) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.PointInt32]: ...
    @winrt_mixinmethod
    def get_ExcludePoints(self: win32more.Microsoft.Windows.AI.Imaging.IImageObjectExtractorHint) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Graphics.PointInt32]: ...
    ExcludePoints = property(get_ExcludePoints, None)
    IncludePoints = property(get_IncludePoints, None)
    IncludeRects = property(get_IncludeRects, None)
class ImageScaler(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IImageScaler
    _classid_ = 'Microsoft.Windows.AI.Imaging.ImageScaler'
    @winrt_mixinmethod
    def ScaleSoftwareBitmap(self: win32more.Microsoft.Windows.AI.Imaging.IImageScaler, softwareBitmap: win32more.Windows.Graphics.Imaging.SoftwareBitmap, width: Int32, height: Int32) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_mixinmethod
    def ScaleImageBuffer(self: win32more.Microsoft.Windows.AI.Imaging.IImageScaler, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer, width: Int32, height: Int32) -> win32more.Microsoft.Graphics.Imaging.ImageBuffer: ...
    @winrt_mixinmethod
    def get_MaxSupportedScaleFactor(self: win32more.Microsoft.Windows.AI.Imaging.IImageScaler) -> Int32: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetReadyState(cls: win32more.Microsoft.Windows.AI.Imaging.IImageScalerStatics) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_classmethod
    def EnsureReadyAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageScalerStatics) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Microsoft.Windows.AI.Imaging.IImageScalerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.ImageScaler]: ...
    MaxSupportedScaleFactor = property(get_MaxSupportedScaleFactor, None)
ImageScalerContract: UInt32 = 65536
class RecognizedLine(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IRecognizedLine
    _classid_ = 'Microsoft.Windows.AI.Imaging.RecognizedLine'
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedLine) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_BoundingBox(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedLine) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedTextBoundingBox: ...
    @winrt_mixinmethod
    def get_Words(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedLine) -> ReceiveArray[win32more.Microsoft.Windows.AI.Imaging.RecognizedWord]: ...
    @winrt_mixinmethod
    def get_Style(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedLine) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedLineStyle: ...
    @winrt_mixinmethod
    def get_LineStyleConfidence(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedLine) -> Single: ...
    BoundingBox = property(get_BoundingBox, None)
    LineStyleConfidence = property(get_LineStyleConfidence, None)
    Style = property(get_Style, None)
    Text = property(get_Text, None)
    Words = property(get_Words, None)
class RecognizedLineStyle(Enum, Int32):
    Handwritten = 0
class RecognizedText(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IRecognizedText
    _classid_ = 'Microsoft.Windows.AI.Imaging.RecognizedText'
    @winrt_mixinmethod
    def get_Lines(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedText) -> ReceiveArray[win32more.Microsoft.Windows.AI.Imaging.RecognizedLine]: ...
    @winrt_mixinmethod
    def get_TextAngle(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedText) -> Single: ...
    Lines = property(get_Lines, None)
    TextAngle = property(get_TextAngle, None)
class RecognizedTextBoundingBox(Structure):
    BottomLeft: win32more.Windows.Foundation.Point
    BottomRight: win32more.Windows.Foundation.Point
    TopLeft: win32more.Windows.Foundation.Point
    TopRight: win32more.Windows.Foundation.Point
class RecognizedWord(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.AI.Imaging.IRecognizedWord
    _classid_ = 'Microsoft.Windows.AI.Imaging.RecognizedWord'
    @winrt_mixinmethod
    def get_Text(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedWord) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_BoundingBox(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedWord) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedTextBoundingBox: ...
    @winrt_mixinmethod
    def get_MatchConfidence(self: win32more.Microsoft.Windows.AI.Imaging.IRecognizedWord) -> Single: ...
    BoundingBox = property(get_BoundingBox, None)
    MatchConfidence = property(get_MatchConfidence, None)
    Text = property(get_Text, None)
TextRecognitionContract: UInt32 = 65536
class TextRecognizer(ComPtr):
    extends: IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Microsoft.Windows.AI.Imaging.ITextRecognizer
    _classid_ = 'Microsoft.Windows.AI.Imaging.TextRecognizer'
    @winrt_mixinmethod
    def RecognizeTextFromImageAsync(self: win32more.Microsoft.Windows.AI.Imaging.ITextRecognizer, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.RecognizedText]: ...
    @winrt_mixinmethod
    def RecognizeTextFromImage(self: win32more.Microsoft.Windows.AI.Imaging.ITextRecognizer, imageBuffer: win32more.Microsoft.Graphics.Imaging.ImageBuffer) -> win32more.Microsoft.Windows.AI.Imaging.RecognizedText: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_classmethod
    def GetReadyState(cls: win32more.Microsoft.Windows.AI.Imaging.ITextRecognizerStatics) -> win32more.Microsoft.Windows.AI.AIFeatureReadyState: ...
    @winrt_classmethod
    def EnsureReadyAsync(cls: win32more.Microsoft.Windows.AI.Imaging.ITextRecognizerStatics) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Microsoft.Windows.AI.AIFeatureReadyResult, Double]: ...
    @winrt_classmethod
    def CreateAsync(cls: win32more.Microsoft.Windows.AI.Imaging.ITextRecognizerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.AI.Imaging.TextRecognizer]: ...


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Input
import win32more.Microsoft.UI.Input.Interop
import win32more.Windows.Devices.Input
class IPenDeviceInteropStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.Interop.IPenDeviceInteropStatics'
    _iid_ = Guid('{c2a59f2a-e077-5d30-a1bd-cf84dd09ee39}')
    @winrt_commethod(6)
    def FromPointerPoint(self, pointerPoint: win32more.Microsoft.UI.Input.PointerPoint) -> win32more.Windows.Devices.Input.PenDevice: ...
class PenDeviceInterop(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Input.Interop.PenDeviceInterop'
    @winrt_classmethod
    def FromPointerPoint(cls: win32more.Microsoft.UI.Input.Interop.IPenDeviceInteropStatics, pointerPoint: win32more.Microsoft.UI.Input.PointerPoint) -> win32more.Windows.Devices.Input.PenDevice: ...


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.BadgeNotifications
class BadgeNotificationGlyph(Enum, Int32):
    None_ = 0
    Activity = 1
    Alarm = 2
    Alert = 3
    Attention = 4
    Available = 5
    Away = 6
    Busy = 7
    Error = 8
    NewMessage = 9
    Paused = 10
    Playing = 11
    Unavailable = 12
class _BadgeNotificationManager_Meta_(ComPtr.__class__):
    pass
class BadgeNotificationManager(ComPtr, metaclass=_BadgeNotificationManager_Meta_):
    extends: IInspectable
    default_interface: win32more.Microsoft.Windows.BadgeNotifications.IBadgeNotificationManager
    _classid_ = 'Microsoft.Windows.BadgeNotifications.BadgeNotificationManager'
    @winrt_mixinmethod
    def SetBadgeAsCount(self: win32more.Microsoft.Windows.BadgeNotifications.IBadgeNotificationManager, notificationCount: UInt32) -> Void: ...
    @winrt_mixinmethod
    def SetBadgeAsGlyph(self: win32more.Microsoft.Windows.BadgeNotifications.IBadgeNotificationManager, glyphValue: win32more.Microsoft.Windows.BadgeNotifications.BadgeNotificationGlyph) -> Void: ...
    @winrt_mixinmethod
    def ClearBadge(self: win32more.Microsoft.Windows.BadgeNotifications.IBadgeNotificationManager) -> Void: ...
    @winrt_classmethod
    def get_Current(cls: win32more.Microsoft.Windows.BadgeNotifications.IBadgeNotificationManagerStatics) -> win32more.Microsoft.Windows.BadgeNotifications.BadgeNotificationManager: ...
    _BadgeNotificationManager_Meta_.Current = property(get_Current, None)
BadgeNotificationsContract: UInt32 = 65536
class IBadgeNotificationManager(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.BadgeNotifications.IBadgeNotificationManager'
    _iid_ = Guid('{11cb6e8f-11ca-53f8-80f6-5330d44ba908}')
    @winrt_commethod(6)
    def SetBadgeAsCount(self, notificationCount: UInt32) -> Void: ...
    @winrt_commethod(7)
    def SetBadgeAsGlyph(self, glyphValue: win32more.Microsoft.Windows.BadgeNotifications.BadgeNotificationGlyph) -> Void: ...
    @winrt_commethod(8)
    def ClearBadge(self) -> Void: ...
class IBadgeNotificationManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.BadgeNotifications.IBadgeNotificationManagerStatics'
    _iid_ = Guid('{a6e71616-7c9f-5d22-ad1c-f4ab874087b5}')
    @winrt_commethod(6)
    def get_Current(self) -> win32more.Microsoft.Windows.BadgeNotifications.BadgeNotificationManager: ...
    Current = property(get_Current, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.UI.Xaml
import win32more.Microsoft.UI.Xaml.Media.Animation
import win32more.Microsoft.UI.Xaml.Navigation
import win32more.Windows.Foundation
import win32more.Windows.UI.Xaml.Interop
class FrameNavigationOptions(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Navigation.IFrameNavigationOptions
    _classid_ = 'Microsoft.UI.Xaml.Navigation.FrameNavigationOptions'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Navigation.FrameNavigationOptions.CreateInstance(*args, None, None))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Navigation.IFrameNavigationOptionsFactory, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Navigation.FrameNavigationOptions: ...
    @winrt_mixinmethod
    def get_IsNavigationStackEnabled(self: win32more.Microsoft.UI.Xaml.Navigation.IFrameNavigationOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsNavigationStackEnabled(self: win32more.Microsoft.UI.Xaml.Navigation.IFrameNavigationOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_TransitionInfoOverride(self: win32more.Microsoft.UI.Xaml.Navigation.IFrameNavigationOptions) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_mixinmethod
    def put_TransitionInfoOverride(self: win32more.Microsoft.UI.Xaml.Navigation.IFrameNavigationOptions, value: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    TransitionInfoOverride = property(get_TransitionInfoOverride, put_TransitionInfoOverride)
class IFrameNavigationOptions(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.IFrameNavigationOptions'
    _iid_ = Guid('{390de593-14cf-5312-af99-6cd8d59ec5d5}')
    @winrt_commethod(6)
    def get_IsNavigationStackEnabled(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IsNavigationStackEnabled(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_TransitionInfoOverride(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_commethod(9)
    def put_TransitionInfoOverride(self, value: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> Void: ...
    IsNavigationStackEnabled = property(get_IsNavigationStackEnabled, put_IsNavigationStackEnabled)
    TransitionInfoOverride = property(get_TransitionInfoOverride, put_TransitionInfoOverride)
class IFrameNavigationOptionsFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.IFrameNavigationOptionsFactory'
    _iid_ = Guid('{ddf3f748-7127-5cee-9f79-ac281a234632}')
    @winrt_commethod(6)
    def CreateInstance(self, baseInterface: IInspectable, innerInterface: POINTER(IInspectable)) -> win32more.Microsoft.UI.Xaml.Navigation.FrameNavigationOptions: ...
class INavigatingCancelEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs'
    _iid_ = Guid('{172fde12-e06f-5df6-930e-5facf7b3fbe7}')
    @winrt_commethod(6)
    def get_Cancel(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_Cancel(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_NavigationMode(self) -> win32more.Microsoft.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_commethod(9)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(10)
    def get_Parameter(self) -> IInspectable: ...
    @winrt_commethod(11)
    def get_NavigationTransitionInfo(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    Cancel = property(get_Cancel, put_Cancel)
    NavigationMode = property(get_NavigationMode, None)
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
class INavigationEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.INavigationEventArgs'
    _iid_ = Guid('{876b70b4-2923-5785-9cea-2e44aa0761bd}')
    @winrt_commethod(6)
    def get_Content(self) -> IInspectable: ...
    @winrt_commethod(7)
    def get_Parameter(self) -> IInspectable: ...
    @winrt_commethod(8)
    def get_NavigationTransitionInfo(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_commethod(9)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(10)
    def get_NavigationMode(self) -> win32more.Microsoft.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_commethod(11)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(12)
    def put_Uri(self, value: win32more.Windows.Foundation.Uri) -> Void: ...
    Content = property(get_Content, None)
    NavigationMode = property(get_NavigationMode, None)
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
    Uri = property(get_Uri, put_Uri)
class INavigationFailedEventArgs(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.INavigationFailedEventArgs'
    _iid_ = Guid('{f808f9a0-130c-5974-87f8-4433271a35a9}')
    @winrt_commethod(6)
    def get_Exception(self) -> win32more.Windows.Foundation.HResult: ...
    @winrt_commethod(7)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(8)
    def put_Handled(self, value: Boolean) -> Void: ...
    @winrt_commethod(9)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Exception = property(get_Exception, None)
    Handled = property(get_Handled, put_Handled)
    SourcePageType = property(get_SourcePageType, None)
class IPageStackEntry(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.IPageStackEntry'
    _iid_ = Guid('{d591f56e-4262-5c91-9d79-29165cd82100}')
    @winrt_commethod(6)
    def get_SourcePageType(self) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_commethod(7)
    def get_Parameter(self) -> IInspectable: ...
    @winrt_commethod(8)
    def get_NavigationTransitionInfo(self) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
class IPageStackEntryFactory(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.IPageStackEntryFactory'
    _iid_ = Guid('{7e5a9469-6108-5e92-a499-5ee9f065a68a}')
    @winrt_commethod(6)
    def CreateInstance(self, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, navigationTransitionInfo: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry: ...
class IPageStackEntryStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.UI.Xaml.Navigation.IPageStackEntryStatics'
    _iid_ = Guid('{2f1d4cb7-923b-59bb-bfc4-750933f28385}')
    @winrt_commethod(6)
    def get_SourcePageTypeProperty(self) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)
class NavigatedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{8631b517-6d8e-58ee-82fe-d4034d1bd7c1}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
class NavigatingCancelEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Navigation.NavigatingCancelEventArgs'
    @winrt_mixinmethod
    def get_Cancel(self: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Cancel(self: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_NavigationMode(self: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> win32more.Microsoft.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_Parameter(self: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_NavigationTransitionInfo(self: win32more.Microsoft.UI.Xaml.Navigation.INavigatingCancelEventArgs) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    Cancel = property(get_Cancel, put_Cancel)
    NavigationMode = property(get_NavigationMode, None)
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
class NavigatingCancelEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{fcae1401-ec94-565f-9f48-7c4b6272b3b1}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Navigation.NavigatingCancelEventArgs) -> Void: ...
class NavigationCacheMode(Enum, Int32):
    Disabled = 0
    Required = 1
    Enabled = 2
class NavigationEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Navigation.NavigationEventArgs'
    @winrt_mixinmethod
    def get_Content(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_Parameter(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs) -> IInspectable: ...
    @winrt_mixinmethod
    def get_NavigationTransitionInfo(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_NavigationMode(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Microsoft.UI.Xaml.Navigation.NavigationMode: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def put_Uri(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationEventArgs, value: win32more.Windows.Foundation.Uri) -> Void: ...
    Content = property(get_Content, None)
    NavigationMode = property(get_NavigationMode, None)
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
    Uri = property(get_Uri, put_Uri)
class NavigationFailedEventArgs(ComPtr):
    extends: IInspectable
    default_interface: win32more.Microsoft.UI.Xaml.Navigation.INavigationFailedEventArgs
    _classid_ = 'Microsoft.UI.Xaml.Navigation.NavigationFailedEventArgs'
    @winrt_mixinmethod
    def get_Exception(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationFailedEventArgs) -> win32more.Windows.Foundation.HResult: ...
    @winrt_mixinmethod
    def get_Handled(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationFailedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def put_Handled(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationFailedEventArgs, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Microsoft.UI.Xaml.Navigation.INavigationFailedEventArgs) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    Exception = property(get_Exception, None)
    Handled = property(get_Handled, put_Handled)
    SourcePageType = property(get_SourcePageType, None)
class NavigationFailedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{97ca2b56-d6eb-5fd2-a675-a339640eedba}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationFailedEventArgs) -> Void: ...
class NavigationMode(Enum, Int32):
    New = 0
    Back = 1
    Forward = 2
    Refresh = 3
class NavigationStoppedEventHandler(MulticastDelegate):
    extends: IUnknown
    _iid_ = Guid('{b9e796a6-7ffe-5a63-aef4-cbc331663b66}')
    @winrt_commethod(3)
    def Invoke(self, sender: IInspectable, e: win32more.Microsoft.UI.Xaml.Navigation.NavigationEventArgs) -> Void: ...
class _PageStackEntry_Meta_(ComPtr.__class__):
    pass
class PageStackEntry(ComPtr, metaclass=_PageStackEntry_Meta_):
    extends: win32more.Microsoft.UI.Xaml.DependencyObject
    default_interface: win32more.Microsoft.UI.Xaml.Navigation.IPageStackEntry
    _classid_ = 'Microsoft.UI.Xaml.Navigation.PageStackEntry'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 3:
            super().__init__(move=win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateInstance(cls: win32more.Microsoft.UI.Xaml.Navigation.IPageStackEntryFactory, sourcePageType: win32more.Windows.UI.Xaml.Interop.TypeName, parameter: IInspectable, navigationTransitionInfo: win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo) -> win32more.Microsoft.UI.Xaml.Navigation.PageStackEntry: ...
    @winrt_mixinmethod
    def get_SourcePageType(self: win32more.Microsoft.UI.Xaml.Navigation.IPageStackEntry) -> win32more.Windows.UI.Xaml.Interop.TypeName: ...
    @winrt_mixinmethod
    def get_Parameter(self: win32more.Microsoft.UI.Xaml.Navigation.IPageStackEntry) -> IInspectable: ...
    @winrt_mixinmethod
    def get_NavigationTransitionInfo(self: win32more.Microsoft.UI.Xaml.Navigation.IPageStackEntry) -> win32more.Microsoft.UI.Xaml.Media.Animation.NavigationTransitionInfo: ...
    @winrt_classmethod
    def get_SourcePageTypeProperty(cls: win32more.Microsoft.UI.Xaml.Navigation.IPageStackEntryStatics) -> win32more.Microsoft.UI.Xaml.DependencyProperty: ...
    NavigationTransitionInfo = property(get_NavigationTransitionInfo, None)
    Parameter = property(get_Parameter, None)
    SourcePageType = property(get_SourcePageType, None)
    _PageStackEntry_Meta_.SourcePageTypeProperty = property(get_SourcePageTypeProperty, None)


make_ready(__name__)



from __future__ import annotations
from win32more.winrt.prelude import *
import win32more.Microsoft.Windows.System.Power
import win32more.Windows.Foundation
class BatteryStatus(Enum, Int32):
    NotPresent = 0
    Discharging = 1
    Idle = 2
    Charging = 3
class DisplayStatus(Enum, Int32):
    Off = 0
    On = 1
    Dimmed = 2
class EffectivePowerMode(Enum, Int32):
    BatterySaver = 0
    BetterBattery = 1
    Balanced = 2
    HighPerformance = 3
    MaxPerformance = 4
    GameMode = 5
    MixedReality = 6
class EnergySaverStatus(Enum, Int32):
    Uninitialized = 0
    Disabled = 1
    Off = 2
    On = 3
class IPowerManagerStatics(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.System.Power.IPowerManagerStatics'
    _iid_ = Guid('{fa3554cc-be1c-534c-bff8-72df78e9f4a4}')
    @winrt_commethod(6)
    def get_EnergySaverStatus(self) -> win32more.Microsoft.Windows.System.Power.EnergySaverStatus: ...
    @winrt_commethod(7)
    def add_EnergySaverStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_EnergySaverStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def get_BatteryStatus(self) -> win32more.Microsoft.Windows.System.Power.BatteryStatus: ...
    @winrt_commethod(10)
    def add_BatteryStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_BatteryStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def get_PowerSupplyStatus(self) -> win32more.Microsoft.Windows.System.Power.PowerSupplyStatus: ...
    @winrt_commethod(13)
    def add_PowerSupplyStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_PowerSupplyStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def get_RemainingChargePercent(self) -> Int32: ...
    @winrt_commethod(16)
    def add_RemainingChargePercentChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_RemainingChargePercentChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def get_RemainingDischargeTime(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(19)
    def add_RemainingDischargeTimeChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(20)
    def remove_RemainingDischargeTimeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(21)
    def get_PowerSourceKind(self) -> win32more.Microsoft.Windows.System.Power.PowerSourceKind: ...
    @winrt_commethod(22)
    def add_PowerSourceKindChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_PowerSourceKindChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def get_DisplayStatus(self) -> win32more.Microsoft.Windows.System.Power.DisplayStatus: ...
    @winrt_commethod(25)
    def add_DisplayStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(26)
    def remove_DisplayStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(27)
    def add_SystemIdleStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(28)
    def remove_SystemIdleStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(29)
    def get_EffectivePowerMode(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.System.Power.EffectivePowerMode]: ...
    @winrt_commethod(30)
    def add_EffectivePowerModeChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_EffectivePowerModeChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def get_UserPresenceStatus(self) -> win32more.Microsoft.Windows.System.Power.UserPresenceStatus: ...
    @winrt_commethod(33)
    def add_UserPresenceStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(34)
    def remove_UserPresenceStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(35)
    def get_SystemSuspendStatus(self) -> win32more.Microsoft.Windows.System.Power.SystemSuspendStatus: ...
    @winrt_commethod(36)
    def add_SystemSuspendStatusChanged(self, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(37)
    def remove_SystemSuspendStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    BatteryStatus = property(get_BatteryStatus, None)
    DisplayStatus = property(get_DisplayStatus, None)
    EffectivePowerMode = property(get_EffectivePowerMode, None)
    EnergySaverStatus = property(get_EnergySaverStatus, None)
    PowerSourceKind = property(get_PowerSourceKind, None)
    PowerSupplyStatus = property(get_PowerSupplyStatus, None)
    RemainingChargePercent = property(get_RemainingChargePercent, None)
    RemainingDischargeTime = property(get_RemainingDischargeTime, None)
    SystemSuspendStatus = property(get_SystemSuspendStatus, None)
    UserPresenceStatus = property(get_UserPresenceStatus, None)
    EnergySaverStatusChanged = event()
    BatteryStatusChanged = event()
    PowerSupplyStatusChanged = event()
    RemainingChargePercentChanged = event()
    RemainingDischargeTimeChanged = event()
    PowerSourceKindChanged = event()
    DisplayStatusChanged = event()
    SystemIdleStatusChanged = event()
    EffectivePowerModeChanged = event()
    UserPresenceStatusChanged = event()
    SystemSuspendStatusChanged = event()
class IPowerManagerStatics2(ComPtr):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.System.Power.IPowerManagerStatics2'
    _iid_ = Guid('{61f3cc25-65b4-5def-9c9b-990cef3b0833}')
    @winrt_commethod(6)
    def get_EffectivePowerMode2(self) -> win32more.Microsoft.Windows.System.Power.EffectivePowerMode: ...
    EffectivePowerMode2 = property(get_EffectivePowerMode2, None)
class _PowerManager_Meta_(ComPtr.__class__):
    pass
class PowerManager(ComPtr, metaclass=_PowerManager_Meta_):
    extends: IInspectable
    _classid_ = 'Microsoft.Windows.System.Power.PowerManager'
    @winrt_classmethod
    def get_EffectivePowerMode2(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics2) -> win32more.Microsoft.Windows.System.Power.EffectivePowerMode: ...
    @winrt_classmethod
    def get_EnergySaverStatus(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.EnergySaverStatus: ...
    @winrt_classmethod
    def add_EnergySaverStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_EnergySaverStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_BatteryStatus(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.BatteryStatus: ...
    @winrt_classmethod
    def add_BatteryStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_BatteryStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_PowerSupplyStatus(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.PowerSupplyStatus: ...
    @winrt_classmethod
    def add_PowerSupplyStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_PowerSupplyStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_RemainingChargePercent(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> Int32: ...
    @winrt_classmethod
    def add_RemainingChargePercentChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RemainingChargePercentChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_RemainingDischargeTime(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_classmethod
    def add_RemainingDischargeTimeChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RemainingDischargeTimeChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_PowerSourceKind(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.PowerSourceKind: ...
    @winrt_classmethod
    def add_PowerSourceKindChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_PowerSourceKindChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_DisplayStatus(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.DisplayStatus: ...
    @winrt_classmethod
    def add_DisplayStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_DisplayStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_SystemIdleStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_SystemIdleStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_EffectivePowerMode(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Microsoft.Windows.System.Power.EffectivePowerMode]: ...
    @winrt_classmethod
    def add_EffectivePowerModeChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_EffectivePowerModeChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_UserPresenceStatus(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.UserPresenceStatus: ...
    @winrt_classmethod
    def add_UserPresenceStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_UserPresenceStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_SystemSuspendStatus(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics) -> win32more.Microsoft.Windows.System.Power.SystemSuspendStatus: ...
    @winrt_classmethod
    def add_SystemSuspendStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, handler: win32more.Windows.Foundation.EventHandler[IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_SystemSuspendStatusChanged(cls: win32more.Microsoft.Windows.System.Power.IPowerManagerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    _PowerManager_Meta_.BatteryStatus = property(get_BatteryStatus, None)
    _PowerManager_Meta_.DisplayStatus = property(get_DisplayStatus, None)
    _PowerManager_Meta_.EffectivePowerMode = property(get_EffectivePowerMode, None)
    _PowerManager_Meta_.EffectivePowerMode2 = property(get_EffectivePowerMode2, None)
    _PowerManager_Meta_.EnergySaverStatus = property(get_EnergySaverStatus, None)
    _PowerManager_Meta_.PowerSourceKind = property(get_PowerSourceKind, None)
    _PowerManager_Meta_.PowerSupplyStatus = property(get_PowerSupplyStatus, None)
    _PowerManager_Meta_.RemainingChargePercent = property(get_RemainingChargePercent, None)
    _PowerManager_Meta_.RemainingDischargeTime = property(get_RemainingDischargeTime, None)
    _PowerManager_Meta_.SystemSuspendStatus = property(get_SystemSuspendStatus, None)
    _PowerManager_Meta_.UserPresenceStatus = property(get_UserPresenceStatus, None)
PowerNotificationsContract: UInt32 = 131072
class PowerSourceKind(Enum, Int32):
    AC = 0
    DC = 1
class PowerSupplyStatus(Enum, Int32):
    NotPresent = 0
    Inadequate = 1
    Adequate = 2
class SystemSuspendStatus(Enum, Int32):
    Uninitialized = 0
    Entering = 1
    AutoResume = 2
    ManualResume = 3
class UserPresenceStatus(Enum, Int32):
    Present = 0
    Absent = 1


make_ready(__name__)
